# MessageEndpointsConfig

A list of the registered message endpoint types, and their config.
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**sms** | [**object**](.md) | The configuration of the sms endpoint type.  | [optional] 
**web_push** | [**MessageEndpointTypeWebPush**](MessageEndpointTypeWebPush.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


